#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# latest update    : 19-03-2007
# source location  : http://mp3gain.sourceforge.net/
# source           : http://switch.dl.sourceforge.net/sourceforge/mp3gain/mp3gain-1_4_6-src.zip

NAME="mp3gain"
CWD=`pwd`
PKG="$CWD/$NAME-install"
SRCNAME="mp3gain-1_4_6-src"
SOURCE="http://switch.dl.sourceforge.net/sourceforge/mp3gain/mp3gain-1_4_6-src.zip"
VERSION="1.4.6"
ARCH="i486"
CPU="i686"
BUILD="48.1"

DOCS="lgpl.txt"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $SRCNAME.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

unzip $SRCNAME.zip -d $NAME-$VERSION

# No configure required, just run make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's/CFLAGS= -Wall -O3/CFLAGS= -O2 -march=i486 -mtune=i686 -Wall/' Makefile
make $numjobs

# install in temporary directory
mkdir -p ../$NAME-install/usr/bin
make install INSTALL_PATH=$PKG/usr/bin

# Strip binaries:
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: MP3Gain analyzes and adjusts mp3s so that they have the same volume
$NAME:
$NAME: MP3Gain does not just do peak normalization, as many normalizers
$NAME: do. Instead, it does some statistical analysis to determine how 
$NAME: loud the file actually sounds to the human ear. Also, the changes
$NAME: MP3Gain makes are completely lossless. There is no quality lost 
$NAME: in the change because the program adjusts the mp3 file directly,
$NAME: without decoding and re-encoding.
$NAME:
$NAME:
$NAME:
END

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
